From fe9a23f542bc56c1c0b6dc30257418e38ff7bd3a Mon Sep 17 00:00:00 2001
From: ftimme <ft@falkotimme.com>
Date: Sat, 08 Jun 2013 18:57:40 -0400
Subject: [PATCH] - Fixed FS#2936 - Please check and limit username input length.

---
 interface/web/sites/shell_user_list.php |    8 +++-----
 1 files changed, 3 insertions(+), 5 deletions(-)

diff --git a/interface/web/sites/shell_user_list.php b/interface/web/sites/shell_user_list.php
index 3909b84..3307d63 100644
--- a/interface/web/sites/shell_user_list.php
+++ b/interface/web/sites/shell_user_list.php
@@ -41,17 +41,15 @@
 * End Form configuration
 ******************************************/
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
 
 $app->uses('listform_actions');
 
 // Limit the results to alias domains
 //$app->listform_actions->SQLExtWhere = "type = 'subdomain'";
 
+$app->listform_actions->SQLOrderBy = 'ORDER BY username';
 $app->listform_actions->onLoad();
 
 

--
Gitblit v1.9.1